import { Schedule } from 'aws-cdk-lib/aws-events';
import { Construct } from 'constructs';
import { LambdaOptions } from './lambda-options';
/**
 * Properties for a MonthlyCostNotifier.
 */
export interface MonthlyCostNotifierProps {
    /**
     * The webhook to post to.
     */
    readonly webhook: string;
    /**
     * The accountId this is being deployed to.
     */
    readonly accountId?: string;
    /**
     * The name of the account this is being deployed to.
     */
    readonly accountName?: string;
    /**
     * User to post to the webhook as
     */
    readonly webhookUser?: string;
    /**
       * The user avatar to use
       */
    readonly webhookAvatar?: string;
    /**
     * The eventbridge rule name
     *
     * @default MonthlyCostNotifierRule
     */
    readonly ruleName?: string;
    /**
     * The eventbridge rule schedule
     *
     * @default - { minute: '0', hour: '15', day: '1', month: '*', year: '*' }
     */
    readonly ruleSchedule?: Schedule;
    /**
     * options to configure the lambda
     */
    readonly lambdaOptions?: LambdaOptions;
}
/**
 * A construct that creates a lambda function bundled with the 'monthly-notifier-lambda' code
 * This is trigger via eventbridge on a schedule to post to a discord webhook for the monthly costs
 *
 * WARNING: This lambda uses a pay per request API. Each call to cost explorer costs $0.01 USD.
 */
export declare class MonthlyCostNotifier extends Construct {
    constructor(scope: Construct, id: string, props: MonthlyCostNotifierProps);
}
